@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -33,7 +33,7 @@ class KPIMTEXTEDIT_EXPORT TextEditFindBarBase : public QWidget
 
 public:
     explicit TextEditFindBarBase(QWidget *parent = nullptr);
-    ~TextEditFindBarBase();
+    ~TextEditFindBarBase() override;
 
     QString text() const;
     void setText(const QString &text);
@@ -52,6 +52,7 @@ protected:
     virtual bool viewIsReadOnly() const = 0;
     virtual bool documentIsEmpty() const = 0;
     virtual bool searchInDocument(const QString &text, QTextDocument::FindFlags searchOptions) = 0;
+    virtual bool searchInDocument(const QRegExp &regExp, QTextDocument::FindFlags searchOptions) = 0;
     virtual void autoSearchMoveCursor() = 0;
 
     bool event(QEvent *e) override;
@@ -78,6 +79,7 @@ private Q_SLOTS:
 
 protected:
     QString mLastSearchStr;
+    QRegExp mLastSearchRegExp;
     TextFindWidget *mFindWidget = nullptr;
     TextReplaceWidget *mReplaceWidget = nullptr;
     bool mHideWhenClose = true;
